searchNodes=[{"doc":"Autoslug field for Ecto.","ref":"EctoAutoslugField.html","title":"EctoAutoslugField","type":"module"},{"doc":"This module defines all the required functions and modules to work with. Examples To create a simple 'Slug' field do: defmodule MyCustomSlug do use EctoAutoslugField.Slug , from : :name_field , to : :slug_field end It is also possible to override get_sources/2 and build_slug/2 functions which are part of the AutoslugField's API. More complex example with the optional sources and custom slug generation function: defmodule MyComplexSlug do use EctoAutoslugField.Slug , to : :slug_field def get_sources ( changeset , _opts ) do basic_fields = [ :name , :surname ] if is_company_info_set ( changeset ) do # We want to track changes in the person&#39;s company: basic_fields ++ [ :company , :position ] else basic_fields end end def build_slug ( sources , changeset ) do super ( sources , changeset ) # Calls the `SlugGenerator.build_slug/1` |&gt; String . replace ( &quot;-&quot; , &quot;+&quot; ) end end It is also possible to always change your slug, even if it was already set: defmodule ThisSlugShouldChange do use EctoAutoslugField.Slug , from : :some_field , to : :slug_field , always_change : true end If you want to change slug for only one instance without setting always_change option, use force_generate_slug/1 function: defmodule SimpleSlugForce do use EctoAutoslugField.Slug , from : :name , to : :some_slug end Then you can use SimpleSlugForce.force_generate_slug(changeset) for any instances, that needs to recreate slugs for some reason. Be careful with these options, since cool URIs do not change .","ref":"EctoAutoslugField.Slug.html","title":"EctoAutoslugField.Slug","type":"module"},{"doc":"This module defines all functions Slug module uses.","ref":"EctoAutoslugField.SlugBase.html","title":"EctoAutoslugField.SlugBase","type":"module"},{"doc":"This function is used to build the slug itself. This function is a place to modify the result slug. For convenience you can call super(sources, changeset) which will return the slug binary. super(sources) uses Slugger , but you can completely change slug-engine to your own. Note: this function will only be called if sources is not empty. Also important this function will be called only once for the normal workflow. And every time for :always_change . So you can do some heavy computations. If for some reason slug should not be set - just return nil or empty binary . It should return a binary or nil .","ref":"EctoAutoslugField.SlugBase.html#build_slug/2","title":"EctoAutoslugField.SlugBase.build_slug/2","type":"function"},{"doc":"This function is used to get sources for the slug. There can be many use cases when this behavior is required, here are the brief examples: Conditional slug sources Add any data from different sources This function should return list of atoms or binaries, or nil . When processing the returned list: atom -key is supposed to identify the model field binary -key is treated as a data itself, it won't be changed","ref":"EctoAutoslugField.SlugBase.html#get_sources/2","title":"EctoAutoslugField.SlugBase.get_sources/2","type":"function"},{"doc":"This function is used to generate slug. It is called 'maybe' since it may not generate slug for several reasons: It was already created and :always_change option was not set The source fields for the slug were empty This function takes changeset as an input and returns changeset.","ref":"EctoAutoslugField.SlugBase.html#maybe_generate_slug/3","title":"EctoAutoslugField.SlugBase.maybe_generate_slug/3","type":"function"},{"doc":"This is just a helper function to check for uniqueness. It basically just wraps Ecto.Changeset and set a proper field name.","ref":"EctoAutoslugField.SlugBase.html#unique_constraint/3","title":"EctoAutoslugField.SlugBase.unique_constraint/3","type":"function"},{"doc":"This module works with slugs itself. It is just a wrapper around 'Slugger'. It is suited for inner use.","ref":"EctoAutoslugField.SlugGenerator.html","title":"EctoAutoslugField.SlugGenerator","type":"module"},{"doc":"This is a public wrapper around do_build_slug/1 functions. Default slug builder.","ref":"EctoAutoslugField.SlugGenerator.html#build_slug/2","title":"EctoAutoslugField.SlugGenerator.build_slug/2","type":"function"},{"doc":"This function conditionally generates slug. This function prepares sources and then calls do_generate_slug/3 .","ref":"EctoAutoslugField.SlugGenerator.html#maybe_generate_slug/3","title":"EctoAutoslugField.SlugGenerator.maybe_generate_slug/3","type":"function"},{"doc":"This module represents a simple wrapper around ':string' Ecto type.","ref":"EctoAutoslugField.Type.html","title":"EctoAutoslugField.Type","type":"module"},{"doc":"Callback implementation for Ecto.Type.cast/1 .","ref":"EctoAutoslugField.Type.html#cast/1","title":"EctoAutoslugField.Type.cast/1","type":"function"},{"doc":"Callback implementation for Ecto.Type.dump/1 .","ref":"EctoAutoslugField.Type.html#dump/1","title":"EctoAutoslugField.Type.dump/1","type":"function"},{"doc":"Callback implementation for Ecto.Type.embed_as/1 .","ref":"EctoAutoslugField.Type.html#embed_as/1","title":"EctoAutoslugField.Type.embed_as/1","type":"function"},{"doc":"Callback implementation for Ecto.Type.equal?/2 .","ref":"EctoAutoslugField.Type.html#equal?/2","title":"EctoAutoslugField.Type.equal?/2","type":"function"},{"doc":"Callback implementation for Ecto.Type.load/1 .","ref":"EctoAutoslugField.Type.html#load/1","title":"EctoAutoslugField.Type.load/1","type":"function"},{"doc":"Callback implementation for Ecto.Type.type/0 .","ref":"EctoAutoslugField.Type.html#type/0","title":"EctoAutoslugField.Type.type/0","type":"function"},{"doc":"Changelog All notable changes to this project will be documented in this file. The format is based on Keep a Changelog , and this project adheres to Semantic Versioning .","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Features Now support elixir&gt;=1.10 Updates ecto to 3.7 Updates bunch of other deps to newer versions Misc Moves from Travis to GitHub Actions Adds mix format support","ref":"changelog.html#v3-0-0-2021-09-12","title":"Changelog - v3.0.0 - 2021-09-12","type":"extras"},{"doc":"Bugfixes Fixed warnings with ecto&gt;=3.2 , see #101","ref":"changelog.html#v2-0-1-2019-10-16","title":"Changelog - v2.0.1 - 2019-10-16","type":"extras"},{"doc":"Breaking features: Now supports elixir&gt;=1.6 Now support only ecto&gt;=3.1 Improvements Adds mix format","ref":"changelog.html#v2-0-0-2019-07-08","title":"Changelog - v2.0.0 - 2019-07-08","type":"extras"},{"doc":"Improvements Adds support for ecto &gt;= 3.0 Adds official support for elixir == 1.6 and elixir == 1.7","ref":"changelog.html#v1-0-0-2018-12-28","title":"Changelog - v1.0.0 - 2018-12-28","type":"extras"},{"doc":"Documentation Updates docs on using force_update_slug","ref":"changelog.html#v0-5-1-2018-05-21","title":"Changelog - v0.5.1 - 2018-05-21","type":"extras"},{"doc":"Improvements Adds force_generate_slug function to the client API. This function may be used when the always_change option of the slug is maybe not set to true but you want to override this setting on the given changeset and force regeneration of the slug Updates multiple dependencies","ref":"changelog.html#v0-5-0-2018-05-21","title":"Changelog - v0.5.0 - 2018-05-21","type":"extras"},{"doc":"Improvements Adds support for numeric, datetime and date fields Updates dependencies, now supports ecto &gt;= 2.1 Documentation Updates README.md with the new ecto version Testing Adds new test cases to cover new field types","ref":"changelog.html#v0-4-0-2017-11-23","title":"Changelog - v0.4.0 - 2017-11-23","type":"extras"},{"doc":"Improvements Adds build_slug/2 to accept the original changeset as the second argument, it still receives list of sources as the first argument Updates build_slug/1 inner logic Documentation Updates README.md with the new example Updates docs to handle new changes Updates CONTRIBUTING.md with 'Development' section Testing Adds new test cases to cover build_slug/2","ref":"changelog.html#v0-3-1-2017-07-19","title":"Changelog - v0.3.1 - 2017-07-19","type":"extras"},{"doc":"Changes breaking Updates mix.exs with new dependencies, closes #14 breaking Drops elixir version 1.2 and otp version 17 support Improvements Updates cast/4 functions to cast/3 functions (new Ecto) Updates credo version and .credo.exs config Updates .travis.yml with credo and new otp release Bugs Fixes dialyxer issues, closes #10 Documentation Updates docs, fixes spelling","ref":"changelog.html#v0-3-0-2017-06-11","title":"Changelog - v0.3.0 - 2017-06-11","type":"extras"},{"doc":"Added credo support Added elixir version 1.4 support","ref":"changelog.html#v0-2-1-2017-02-01","title":"Changelog - v0.2.1 - 2017-02-01","type":"extras"},{"doc":"Since this version only ecto 2 and above are supported Updated docs on how to use this package with older ecto Credo is not working with this release, please see https://github.com/sobolevn/ecto_autoslug_field/issues/5","ref":"changelog.html#v0-2-0-2016-11-02","title":"Changelog - v0.2.0 - 2016-11-02","type":"extras"},{"doc":"Now build_slug/1 is called only when needed, changed docs appropriately Replaced cond inside do_generate_slug/3 with more obvious if Changed tests structure, reached 100% coverage","ref":"changelog.html#v0-1-3-2016-07-22","title":"Changelog - v0.1.3 - 2016-07-22","type":"extras"},{"doc":"Moved get_sources/2 and build_slug/1 definitions into SlugBase Added ## Options and ## Function section to the README.md Added new tests","ref":"changelog.html#v0-1-2-2016-07-21","title":"Changelog - v0.1.2 - 2016-07-21","type":"extras"},{"doc":"Since the docs inside __using__ were unreachable the design of application was changed Now opts keyword-list contains :slug_build parameter with a build_slug callback Also coverage information is updated, since more code is reachable now","ref":"changelog.html#v0-1-1-2016-07-21","title":"Changelog - v0.1.1 - 2016-07-21","type":"extras"},{"doc":"Initial release","ref":"changelog.html#v0-1-0-2016-07-21","title":"Changelog - v0.1.0 - 2016-07-21","type":"extras"},{"doc":"The MIT License (MIT) Copyright (c) 2016 Nikita Sobolev Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html","title":"License","type":"extras"},{"doc":"EctoAutoslugField ecto_autoslug_field is a reusable Ecto library which can automatically create slugs from other fields. We use slugger as a default slug-engine. We only depend on the ecto package (we do not deal with ecto_sql at all). We support ecto &gt;= 3.7 and ecto &lt; 4 ! See this blog post for more information.","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"def deps do [ { :ecto_autoslug_field , &quot;~&gt; 3.0&quot; } ] end","ref":"readme.html#installation","title":"Overview - Installation","type":"extras"},{"doc":"There are several options to configure. Required: :to - represents the slug field name where to save value to Optional: :from - represents the source fields from which to build slug, if this option is not set you have to override get_sources/2 function :always_change - if this option is set slug will be recreated from the given sources each time maybe_generate_slug function is called","ref":"readme.html#options","title":"Overview - Options","type":"extras"},{"doc":"get_sources/2 - this function is used to get sources for the slug, docs . build_slug/2 - this function is a place to modify the result slug, docs .","ref":"readme.html#functions","title":"Overview - Functions","type":"extras"},{"doc":"The simplest example: defmodule EctoSlugs.Blog.Article.TitleSlug do use EctoAutoslugField.Slug , from : :title , to : :slug end defmodule EctoSlugs.Blog.Article do use Ecto.Schema import Ecto.Changeset alias EctoSlugs.Blog.Article alias EctoSlugs.Blog.Article.TitleSlug schema &quot;blog_articles&quot; do field :breaking , :boolean , default : false field :content , :string field :title , :string field :slug , TitleSlug.Type timestamps ( ) end def changeset ( model , params \\\\ :invalid ) do model |&gt; cast ( params , [ :title , :content , :breaking ] ) |&gt; validate_required ( [ :title , :content ] ) |&gt; unique_constraint ( :title ) |&gt; TitleSlug . maybe_generate_slug ( ) |&gt; TitleSlug . unique_constraint ( ) end end See this tutorial for some more examples.","ref":"readme.html#examples","title":"Overview - Examples","type":"extras"},{"doc":"See CHANGELOG.md .","ref":"readme.html#changelog","title":"Overview - Changelog","type":"extras"},{"doc":"Copyright (c) 2016 Nikita Sobolev This library is released under the MIT License. See the LICENSE.md file for further details.","ref":"readme.html#copyright-and-license","title":"Overview - Copyright and License","type":"extras"}]